Constants class
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- altchaChallengeUrl → const String
- botDetectionRiskThreshold → const int
- captchaBaseUrl → const String
- loginBaseUrl → const String
- newCaptchaUrl → const String
- saveCaptchaLogUrl → const String
- sliderBaseUrl → const String
- triShieldBaseUrl → const String
- verifyCaptchaUrl → const String
- verifyUserKeyUrl → const String