DeviceFingerprint class
Constructors
- DeviceFingerprint({required String platform, required String device, String? brand, String? model, required String osVersion, required bool isPhysicalDevice, required bool isRooted, required bool isDevelopmentMode, double? sensorVariance, int? batteryLevel, String? batteryState, String? networkType, required String hash, required int timestamp})
-
const
-
DeviceFingerprint.fromJson(Map<
String, dynamic> json) -
factory
Properties
- batteryLevel → int?
-
final
- batteryState → String?
-
final
- brand → String?
-
final
- device → String
-
final
- hash → String
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- isDevelopmentMode → bool
-
final
- isPhysicalDevice → bool
-
final
- isRooted → bool
-
final
- model → String?
-
final
- networkType → String?
-
final
- osVersion → String
-
final
- platform → String
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- sensorVariance → double?
-
final
- timestamp → int
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited